@@ -27,9 +27,9 @@ __author__ = "Christian Staudt"
 __copyright__ = "Copyright (c) 2014 Christan Staudt"
 __credits__ = ["Lukas Barth", "Miriam Beddig", "Elisabetta Bergamini", "Stefan Bertsch", "Pratistha Bhattarai", "Andreas Bilke", "Simon Bischof", \
 	"Guido Brückner", "Mark Erb", "Patrick Flick", "Michael Hamann", "Lukas Hartmann", "Daniel Hoske", "Gerd Lindner", "Moritz v. Looz", "Yassine Marrakchi", "Henning Meyerhenke", \
-	"Marcel Radermacher", "Klara Reichard", "Marvin Ritter", "Aleksejs Sazonovs", "Florian Weber", "Michael Wegner", "Jörg Weisbarth"]
+	"Marcel Radermacher", "Klara Reichard", "Marvin Ritter", "Aleksejs Sazonovs", "Florian Weber", "Michael Wegner", "Jörg Weisbarth", "Kolja Esders"]
 __license__ = "MIT"
-__version__ = "4.1.1"
+__version__ = "4.5"
 
 
 # standard library modules
@@ -67,6 +67,7 @@ from . import coarsening
 from . import simulation
 from . import stats
 from . import sampling
+from . import viz
 from .profiling import profiling
 
 try:
@@ -100,6 +101,7 @@ def overview(G):
 	"""
 	n = G.numberOfNodes()
 	degrees = centrality.DegreeCentrality(G,ignoreSelfLoops=G.numberOfSelfLoops() == 0).run().scores()
+	numSelfLoops = G.numberOfSelfLoops()
 	def getIsolatedNodes(degrees):
 		sequence = sorted(degrees)
 		i = 0
@@ -123,9 +125,10 @@ def overview(G):
 	print("directed?\t\t\t{}".format("True" if G.isDirected() else "False"))
 	print("weighted?\t\t\t{}".format("True" if G.isWeighted() else "False"))
 	print("isolated nodes\t\t\t{}".format(getIsolatedNodes(degrees)))
-	print("self-loops\t\t\t{}".format(G.numberOfSelfLoops()))
+	print("self-loops\t\t\t{}".format(numSelfLoops))
 	print("density\t\t\t\t{:.6f}".format(G.density()))
-	print("clustering coefficient\t\t{:.6f}".format(getClusteringCoefficient(G)))
+	if numSelfLoops == 0 and not G.isDirected():
+		print("clustering coefficient\t\t{:.6f}".format(getClusteringCoefficient(G)))
 	print("min/max/avg degree\t\t{:d}, {:d}, {:.6f}".format(int(min(degrees)), int(max(degrees)), sum(degrees)/n))
 	print("degree assortativity\t\t{:.6f}".format(correlation.Assortativity(G, degrees).run().getCoefficient()))
 	cp = getComponentPartition(G)
