@@ -14,15 +14,20 @@ Timer::Timer() : running(false) {
 
 my_steady_clock::time_point Timer::start() {
 	this->started = my_steady_clock::now();
+	running = true;
 	return this->started;
 }
 
 my_steady_clock::time_point Timer::stop() {
 	this->stopped = my_steady_clock::now();
+	running = false;
 	return this->stopped;
 }
 
 std::chrono::duration<uint64_t, std::milli> Timer::elapsed() const {
+	if (running) {
+		return std::chrono::duration_cast<std::chrono::duration<uint64_t, std::milli>>(std::chrono::steady_clock::now() - this->started);
+	}
 	std::chrono::duration<uint64_t, std::milli> elapsed = std::chrono::duration_cast<std::chrono::duration<uint64_t, std::milli>>(this->stopped - this->started);
 	return elapsed;
 }
@@ -55,4 +60,3 @@ std::string Timer::elapsedTag() {
 
 
 } /* namespace Aux */
-
