@@ -8,12 +8,8 @@ namespace NetworKit {
 
 	}
 
-	bool Algorithm::hasFinished() const {
-		return hasRun;
-	}
-
 	std::string Algorithm::toString() const {
-		return "Algorithm base class";
+		throw std::runtime_error("TODO: implement in subclass and return string representation");
 	}
 
 	bool Algorithm::isParallel() const {
