@@ -15,9 +15,9 @@
 #include "../auxiliary/PrioQueue.h"
 #include "../auxiliary/Log.h"
 #include "../auxiliary/SignalHandling.h"
-#include "../graph/SSSP.h"
-#include "../graph/Dijkstra.h"
-#include "../graph/BFS.h"
+#include "../distance/SSSP.h"
+#include "../distance/Dijkstra.h"
+#include "../distance/BFS.h"
 
 namespace NetworKit {
 
@@ -62,7 +62,7 @@ void Betweenness::run() {
 		sssp->run();
 		if (!handler.isRunning()) return;
 		// compute dependencies for nodes in order of decreasing distance from s
-		std::vector<node> stack = sssp->getStack();
+		std::vector<node> stack = sssp->getNodesSortedByDistance();
 		while (!stack.empty()) {
 			node t = stack.back();
 			stack.pop_back();
