@@ -34,6 +34,13 @@ void GraphEventProxy::removeNode(node u) {
 	}
 }
 
+void GraphEventProxy::restoreNode(node u) {
+	this->G->restoreNode(u);
+//	TRACE("restoring node " , u);
+	for (GraphEventHandler* observer : this->observers) {
+		observer->onNodeRestoration(u);
+	}
+}
 void GraphEventProxy::addEdge(node u, node v, edgeweight weight) {
 	this->G->addEdge(u, v, weight);
 //	TRACE("adding edge (" , u , "," , v , ")");
@@ -60,6 +67,14 @@ void GraphEventProxy::setWeight(node u, node v, edgeweight w) {
 	}
 }
 
+void GraphEventProxy::incrementWeight(node u, node v, edgeweight delta) {
+//	TRACE("incrementing weight of edge (" , u , "," , v , ") by " , delta);
+	edgeweight wOld = this->G->weight(u, v);
+	this->G->setWeight(u, v, wOld+delta);
+	for (GraphEventHandler* observer : this->observers) {
+		observer->onWeightIncrement(u, v, wOld, delta);
+	}
+}
 
 void GraphEventProxy::timeStep() {
 //	TRACE("time step");
