@@ -18,19 +18,17 @@ void GraphUpdater::update(std::vector<GraphEvent>& stream) {
 		TRACE("event: " , ev.toString());
 		switch (ev.type) {
 			case GraphEvent::NODE_ADDITION : {
-#if (LOG_LEVEL == LOG_LEVEL_TRACE)
-				node u = G.addNode();
-				TRACE("added node " , u, ", ev.u: ", ev.u);
-#else
 				G.addNode();
-#endif
-				assert (u == ev.u);
 				break;
 			}
 			case GraphEvent::NODE_REMOVAL : {
 				G.removeNode(ev.u);
 				break;
 			}
+			case GraphEvent::NODE_RESTORATION :{
+				G.restoreNode(ev.u);
+				break;
+			}
 			case GraphEvent::EDGE_ADDITION : {
 				G.addEdge(ev.u, ev.v, ev.w);
 				break;
@@ -43,6 +41,10 @@ void GraphUpdater::update(std::vector<GraphEvent>& stream) {
 				G.setWeight(ev.u, ev.v, ev.w);
 				break;
 			}
+			case GraphEvent::EDGE_WEIGHT_INCREMENT : {
+				G.setWeight(ev.u, ev.v, G.weight(ev.u, ev.v) + ev.w);
+				break;
+			}
 			case GraphEvent::TIME_STEP : {
 				G.timeStep();
 				break;
@@ -61,6 +63,3 @@ std::vector<std::pair<count, count> > GraphUpdater::getSizeTimeline() {
 }
 
 } /* namespace NetworKit */
-
-
-
