@@ -33,7 +33,6 @@ private:
 	count dimension;
 	unsigned capacity;
 	static const unsigned coarsenLimit = 4;
-	static const long unsigned sanityNodeLimit = 10E15; //just assuming, for debug purposes, that this algorithm never runs on machines with more than 4 Petabyte RAM
 	count subTreeSize;
 	std::vector<T> content;
 	std::vector<Point<double> > positions;
@@ -49,15 +48,10 @@ public:
 	 * Construct a QuadNode for polar coordinates.
 	 *
 	 *
-	 * @param leftAngle Minimal angular coordinate of region, in radians from 0 to 2\pi
-	 * @param rightAngle Maximal angular coordinate of region, in radians from 0 to 2\pi
-	 * @param minR Minimal radial coordinate of region, between 0 and 1
-	 * @param maxR Maximal radial coordinate of region, between 0 and 1
+	 * @param lower Minimal coordinates of region
+	 * @param upper Maximal coordinates of region (excluded)
 	 * @param capacity Number of points a leaf cell can store before splitting
-	 * @param minDiameter Minimal diameter of a quadtree node. If the node is already smaller, don't split even if over capacity. Default is 0
 	 * @param splitTheoretical Whether to split in a theoretically optimal way or in a way to decrease measured running times
-	 * @param alpha dispersion Parameter of the point distribution. Only has an effect if theoretical split is true
-	 * @param diagnostics Count how many necessary and unnecessary comparisons happen in leaf cells? Will cause race condition and false sharing in parallel use
 	 *
 	 */
 	QuadNodeCartesianEuclid(Point<double> lower = Point<double>({0.0, 0.0}), Point<double> upper = Point<double>({1.0, 1.0}), unsigned capacity = 1000, bool splitTheoretical = false) {
@@ -127,7 +121,6 @@ public:
 	 * @param R radial coordinate of point, between 0 and 1.
 	 */
 	void addContent(T input, Point<double> pos) {
-		assert(input < sanityNodeLimit);
 		assert(content.size() == positions.size());
 		assert(this->responsible(pos));
 		if (isLeaf) {
@@ -352,11 +345,9 @@ public:
 			const double rsq = radius*radius;
 			const count cSize = content.size();
 
-			for (int i=0; i < cSize; i++) {
+			for (index i=0; i < cSize; i++) {
 				if (positions[i].squaredDistance(center) < rsq) {
 					result.push_back(content[i]);
-					if (content[i] >= sanityNodeLimit) DEBUG("Quadnode content ", content[i], " found, suspiciously high!");
-					assert(content[i] < sanityNodeLimit);
 				}
 			}
 		}	else {
@@ -388,7 +379,7 @@ public:
 		if (isLeaf) {
 			const count lsize = content.size();
 			TRACE("Leaf of size ", lsize);
-			for (int i = 0; i < lsize; i++) {
+			for (index i = 0; i < lsize; i++) {
 				//jump!
 				if (probUB < 1) {
 					double random = Aux::Random::real();
@@ -529,15 +520,14 @@ public:
 	}
 
 	index getCellID(Point<double> pos) const {
-		if (!responsible(pos)) return -1;
+		if (!responsible(pos)) return NetworKit::none;
 		if (isLeaf) return getID();
 		else {
 			for (int i = 0; i < children.size(); i++) {
 				index childresult = children[i].getCellID(pos);
-				if (childresult >= 0) return childresult;
+				if (childresult != NetworKit::none) return childresult;
 			}
-			assert(false); //if responsible
-			return -1;
+			throw std::runtime_error("No responsible child node found even though this node is responsible.");
 		}
 	}
 
