@@ -510,9 +510,13 @@ void Graph::removeNode(node v) {
 	assert (v < z);
 	assert (exists[v]);
 
-	if (!isIsolated(v)) {
-		throw std::runtime_error("nodes must be isolated (degree 0) before they can be removed");
-	}
+  // Remove all out- and incoming edges
+	this->forEdgesOf(v, [&](node u) {
+		removeEdge(v, u);
+	});
+	this->forInEdgesOf(v, [&](node u) {
+		removeEdge(u, v);
+	});
 
 	exists[v] = false;
 	n--;
@@ -761,6 +765,9 @@ std::pair<node, node> Graph::randomEdge(bool uniformDistribution) const {
 }
 
 std::vector< std::pair<node, node> > Graph::randomEdges(count nr) const {
+	if (numberOfEdges() == 0) {
+		throw std::runtime_error("Graph has no edges to sample from. Add edges to the graph first.");
+	}
 	std::vector< std::pair<node, node> > edges;
 
 	std::default_random_engine gen{std::random_device{}()};
