@@ -247,7 +247,7 @@ private:
 	 * error messages from the other declarations.
 	 */
 	template<class F, void* = (void*)0>
-	typename Aux::FunctionTraits<F>::result_type edgeLambda(F&f, ...) const {
+	typename Aux::FunctionTraits<F>::result_type edgeLambda(F&, ...) const {
 		// the strange condition is used in order to delay the eveluation of the static assert to the moment when this function is actually used
 		static_assert(! std::is_same<F, F>::value, "Your lambda does not support the required parameters or the parameters have the wrong type.");
 		return std::declval<typename Aux::FunctionTraits<F>::result_type>(); // use the correct return type (this won't compile)
@@ -278,7 +278,7 @@ private:
 			 std::is_same<edgeid, typename Aux::FunctionTraits<F>::template arg<2>::type>::value &&
 			 std::is_same<node, typename Aux::FunctionTraits<F>::template arg<1>::type>::value /* prevent f(v, weight, eid) */
 			 >::type* = (void*)0>
-	auto edgeLambda(F&f, node u, node v, edgeweight ew, edgeid id) const -> decltype(f(u, v, id)) {
+	auto edgeLambda(F&f, node u, node v, edgeweight, edgeid id) const -> decltype(f(u, v, id)) {
 		return f(u, v, id);
 	}
 
@@ -291,7 +291,7 @@ private:
 			 (Aux::FunctionTraits<F>::arity >= 2) &&
 			 std::is_same<edgeweight, typename Aux::FunctionTraits<F>::template arg<2>::type>::value
 			 >::type* = (void*)0>
-	auto edgeLambda(F&f, node u, node v, edgeweight ew, edgeid id) const -> decltype(f(u, v, ew)) {
+	auto edgeLambda(F&f, node u, node v, edgeweight ew, edgeid /*id*/) const -> decltype(f(u, v, ew)) {
 		return f(u, v, ew);
 	}
 
@@ -306,7 +306,7 @@ private:
 			 (Aux::FunctionTraits<F>::arity >= 1) &&
 			 std::is_same<node, typename Aux::FunctionTraits<F>::template arg<1>::type>::value
 			 >::type* = (void*)0>
-	auto edgeLambda(F&f, node u, node v, edgeweight ew, edgeid id) const -> decltype(f(u, v)) {
+	auto edgeLambda(F&f, node u, node v, edgeweight /*ew*/, edgeid /*id*/) const -> decltype(f(u, v)) {
 			return f(u, v);
 	}
 
@@ -320,7 +320,7 @@ private:
 			 (Aux::FunctionTraits<F>::arity >= 1) &&
 			 std::is_same<edgeweight, typename Aux::FunctionTraits<F>::template arg<1>::type>::value
 			 >::type* = (void*)0>
-	auto edgeLambda(F&f, node u, node v, edgeweight ew, edgeid id) const -> decltype(f(u, ew)) {
+	auto edgeLambda(F&f, node u, node v, edgeweight ew, edgeid /*id*/) const -> decltype(f(u, ew)) {
 		return f(v, ew);
 	}
 
@@ -331,7 +331,7 @@ private:
 	 */
 	template<class F,
 			 void* = (void*)0>
-	auto edgeLambda(F&f, node u, node v, edgeweight ew, edgeid id) const -> decltype(f(v)) {
+	auto edgeLambda(F&f, node, node v, edgeweight, edgeid) const -> decltype(f(v)) {
 		return f(v);
 	}
 
@@ -348,7 +348,7 @@ private:
 	 * Calls the given BFS handle without distance parameter
 	 */
 	template <class F>
-	auto callBFSHandle(F &f, node u, count dist) const -> decltype(f(u)) {
+	auto callBFSHandle(F &f, node u, count) const -> decltype(f(u)) {
 		return f(u);
 	}
 
@@ -504,13 +504,11 @@ public:
 	node addNode(float x, float y);
 
 	/**
-	 * Remove an isolated node @a v from the graph.
+	 * Remove a node @a v and all incident edges from the graph.
+	 *
+	 * Incoming as well as outgoing edges will be removed.
 	 *
 	 * @param u Node.
-	 * @note Although it would be convenient to remove all incident edges at the same time,
-	 * this causes complications for dynamic applications. Therefore, removeNode is an
-	 * atomic event. All incident edges need to be removed first and an exception is thrown
-	 * otherwise.
 	 */
 	void removeNode(node v);
 
@@ -717,7 +715,7 @@ public:
 	/**
 	* @return a pair (n, m) where n is the number of nodes and m is the number of edges
 	*/
-	std::pair<count, count> const size() { return {n, m}; };
+	std::pair<count, count> const size() const { return {n, m}; };
 
 
 	/**
@@ -901,6 +899,24 @@ public:
 	 */
 	std::vector<node> neighbors(node u) const;
 
+	/**
+	 * Get i-th (outgoing) neighbor of @a u.
+	 * WARNING: This function is deprecated or only temporary.
+	 *
+	 * @param u Node.
+	 * @param i index; should be in [0, degreeOut(u))
+	 * @return @a i -th (outgoing) neighbor of @a u, or @c none if no such
+	 * neighbor exists.
+	 */
+	template<bool graphIsDirected>
+	node getIthNeighbor(node u, index i) const {
+		node v = outEdges[u][i];
+		if (useEdgeInIteration<graphIsDirected>(u, v))
+			return v;
+		else
+			return none;
+	}
+
 
 	/* Derivative Graphs */
 
@@ -1202,7 +1218,7 @@ inline edgeid Graph::getInEdgeId<false>(node, index) const {
 
 
 template<bool graphIsDirected> // implementation for graphIsDirected == true
-inline bool Graph::useEdgeInIteration(node u, node v) const {
+inline bool Graph::useEdgeInIteration(node /* u */, node v) const {
 	return v != none;
 }
 
