@@ -28,11 +28,6 @@ public:
 	 * @param[in]	path	input file path
 	 */
 	virtual Graph read(const std::string& path) = 0;
-
-	/** only to be used by cython - this eliminates an unnecessary copy */
-	Graph* _read(const std::string& path) {
-		return new Graph{std::move(read(path))};
-	};
 };
 
 } /* namespace NetworKit */
