@@ -22,7 +22,7 @@ class GraphWriter {
 public:
 	virtual ~GraphWriter() = default;
 
-	virtual void write(Graph& G, const std::string& path) = 0;
+	virtual void write(const Graph& G, const std::string& path) = 0;
 };
 
 } /* namespace NetworKit */
