@@ -25,10 +25,7 @@ public:
      * Detect communities for given seed nodes.
      * @return a mapping from seed node to community (as a set of nodes)
      */
-	virtual std::map<node, std::set<node> >  run(std::set<unsigned int>& seeds) = 0;
-
-	// FIXME: resolve Cython issue that does not allow a uint64_t as content type of a container as input
-
+	virtual std::map<node, std::set<node> >  run(const std::set<node>& seeds) = 0;
 
 protected:
 
