@@ -15,13 +15,10 @@
 #include <cassert>
 #include <limits>
 #include "Partition.h"
-
+#include "../Globals.h"
 
 namespace NetworKit {
 
-typedef uint64_t index;
-typedef uint64_t count;
-
 /**
  * @ingroup structures
  * Implements a cover of a set, i.e. an assignment of
