@@ -18,7 +18,7 @@ from IPython.core.display import *
 import collections
 import math
 import fnmatch
-
+import random
 
 # colors
 colors = {
@@ -101,7 +101,8 @@ class Config:
 	def __init__(self):
 		""" constructor: all options off """
 		self.__options_Properties = {
-			"Diameter": False
+			"Diameter": False,
+			"EffectiveDiameter": False
 		}
 		self.__options_Measures = {
 			"Centrality.Degree": False,
@@ -129,6 +130,7 @@ class Config:
 
 		if preset == "complete":
 			result.setProperty("Diameter")
+			result.setProperty("EffectiveDiameter")
 			result.setMeasure("Centrality.Degree"),
 			result.setMeasure("Centrality.CoreDecomposition")
 			result.setMeasure("Centrality.ClusteringCoefficient")
@@ -204,6 +206,7 @@ class Profile:
 
 	__TOKEN = object()	# see __init__(): prevent this class from being instanced directly
 	__pageCount = 0
+	__token = ""
 	__verbose = False
 	__verboseLevel = 0
 	__verboseFilename = ""
@@ -219,6 +222,7 @@ class Profile:
 		self.__measures = collections.OrderedDict()
 		self.__correlations = {}
 
+		self.__token = ''.join(random.choice('0123456789abcdef') for n in range(16))
 
 
 
@@ -373,7 +377,8 @@ class Profile:
 			style = style,
 			color = color,
 			pageIndex = 0,
-			parallel = parallel
+			parallel = parallel,
+			token = self.__token,
 		)
 
 		if outputType == "HTML":
@@ -434,6 +439,7 @@ class Profile:
 			filename = "",
 			style = style,
 			color = color,
+			token = self.__token,
 			pageIndex = self.__pageCount,
 			parallel = parallel
 		)
@@ -442,7 +448,7 @@ class Profile:
 		self.__pageCount = self.__pageCount + 1
 
 
-	def __format(self, outputType, directory, filename, style, color, pageIndex, parallel):
+	def __format(self, outputType, directory, filename, style, color, token, pageIndex, parallel):
 		""" layouts the profile	"""
 		confParser = configparser.ConfigParser()
 		confParser.read(getfilepath("description/descriptions.txt"))
@@ -677,6 +683,7 @@ class Profile:
 
 		result = self.__formatProfileTemplate(
 			templateProfile,
+			token,
 			pageIndex,
 			results
 		)
@@ -689,7 +696,7 @@ class Profile:
 		return result
 
 
-	def __formatProfileTemplate(self, template, pageIndex, results):
+	def __formatProfileTemplate(self, template, token, pageIndex, results):
 		""" format profile template - all function parameters, are available for the template """
 		properties = self.__properties
 		result = template.format(**locals())
@@ -731,17 +738,34 @@ class Profile:
 			try:
 				timerInstance = stopwatch.Timer()
 				self.verbosePrint("Diameter: ", end="")
-				diameter = distance.Diameter.estimatedDiameterRange(self.__G, error=0.1)
+				diam = distance.Diameter(self.__G, distance.DiameterAlgo.EstimatedRange, error = 0.1)
+				diameter = diam.run().getDiameter()
 				elapsedMain = timerInstance.elapsed
 				self.verbosePrint("{:.2F} s".format(elapsedMain))
 				self.verbosePrint("")
-			except:
-				self.verbosePrint("Diameter raised exception")
+			except Exception as e:
+				self.verbosePrint("Diameter raised exception: {}".format(e))
 				diameter = "N/A"
 		else:
 			diameter = "N/A"
 		self.__properties["Diameter Range"] = diameter
 
+		if self.__config.getProperty("EffectiveDiameter"):
+			try:
+				timerInstance = stopwatch.Timer()
+				self.verbosePrint("EffectiveDiameter: ", end="")
+				diam = distance.ApproxEffectiveDiameter(self.__G)
+				diameter = diam.run().getEffectiveDiameter()
+				elapsedMain = timerInstance.elapsed
+				self.verbosePrint("{:.2F} s".format(elapsedMain))
+				self.verbosePrint("")
+			except:
+				self.verbosePrint("EffectiveDiameter raised exception")
+				diameter = "N/A"
+		else:
+			diameter = "N/A"
+		self.__properties["Effective Diameter"] = diameter
+
 
 		timerInstance = stopwatch.Timer()
 		self.verbosePrint("Connected Components: ", end="")
