@@ -34,7 +34,7 @@ def extractLargestComponent(G):
 	(largestCompo, size) = max(cSizes.items(), key=operator.itemgetter(1))
 	logging.info("extracting component {0} containing {1} nodes".format(largestCompo, size))
 	compoNodes = [v for v in G.nodes() if cc.componentOfNode(v) is largestCompo]
-	C = graph.Subgraph().fromNodes(G, compoNodes)
+	C = G.subgraphFromNodes(compoNodes)
 	return C
 
 
