@@ -1,6 +1,6 @@
 name='networkit'
 
-version='4.1.1'
+version='4.5'
 
 url='https://networkit.iti.kit.edu/'
 
@@ -44,6 +44,7 @@ classifiers = [
 'Programming Language :: Python :: 3.3',
 'Programming Language :: Python :: 3.4',
 'Programming Language :: Python :: 3.5',
+'Programming Language :: Python :: 3.6',
 'Topic :: Software Development :: Libraries :: Python Modules',
 'Topic :: Scientific/Engineering :: Bio-Informatics',
 'Topic :: Scientific/Engineering :: Chemistry',
@@ -53,5 +54,6 @@ classifiers = [
 
 install_requires = []
 # not used because it can mess up pip's installation process
-# therefore, setup.py prints warnings for each package missing (tabulate, readline, scipy, numpy, matplotlib, networkx)
-# or terminates the installation process (gcc, scons and cython)
+# therefore, setup.py prints installs the missing packages (tabulate, readline, scipy, numpy, matplotlib, networkx, cython)
+# If gcc is missing, the installation is stopped.
+# In case scons is missing, the installation continues the build within the mbe.MinimalBuildEnvironment.
